@@ -10,12 +10,44 @@ import sys
 import warnings
 
 
-__version__ = "2.10.0"
+__version__ = "2.10.1"
 __author__ = "Kostiantyn Rybnikov"
 __author_email__ = "k-bx@k-bx.com"
 __maintainer__ = ["Sebastien Celles", "Tom Schraitle"]
 __maintainer_email__ = "s.celles@gmail.com"
 
+#: Our public interface
+__all__ = (
+    #
+    # Module level function:
+    "bump_build",
+    "bump_major",
+    "bump_minor",
+    "bump_patch",
+    "bump_prerelease",
+    "compare",
+    "deprecated",
+    "finalize_version",
+    "format_version",
+    "match",
+    "max_ver",
+    "min_ver",
+    "parse",
+    "parse_version_info",
+    "replace",
+    #
+    # CLI interface
+    "cmd_bump",
+    "cmd_check",
+    "cmd_compare",
+    "createparser",
+    "main",
+    "process",
+    #
+    # Constants and classes
+    "SEMVER_SPEC_VERSION",
+    "VersionInfo",
+)
 
 #: Contains the implemented semver.org version of the spec
 SEMVER_SPEC_VERSION = "2.0.0"
@@ -296,7 +328,7 @@ class VersionInfo(object):
         untouched.
 
         :return: new object with the raised major part
-        :rtype: VersionInfo
+        :rtype: :class:`VersionInfo`
 
         >>> ver = semver.VersionInfo.parse("3.4.5")
         >>> ver.bump_major()
@@ -311,7 +343,7 @@ class VersionInfo(object):
         untouched.
 
         :return: new object with the raised minor part
-        :rtype: VersionInfo
+        :rtype: :class:`VersionInfo`
 
         >>> ver = semver.VersionInfo.parse("3.4.5")
         >>> ver.bump_minor()
@@ -326,7 +358,7 @@ class VersionInfo(object):
         untouched.
 
         :return: new object with the raised patch part
-        :rtype: VersionInfo
+        :rtype: :class:`VersionInfo`
 
         >>> ver = semver.VersionInfo.parse("3.4.5")
         >>> ver.bump_patch()
@@ -342,7 +374,7 @@ class VersionInfo(object):
 
         :param token: defaults to 'rc'
         :return: new object with the raised prerelease part
-        :rtype: str
+        :rtype: :class:`VersionInfo`
 
         >>> ver = semver.VersionInfo.parse("3.4.5-rc.1")
         >>> ver.bump_prerelease()
@@ -360,7 +392,7 @@ build=None)
 
         :param token: defaults to 'build'
         :return: new object with the raised build part
-        :rtype: str
+        :rtype: :class:`VersionInfo`
 
         >>> ver = semver.VersionInfo.parse("3.4.5-rc.1+build.9")
         >>> ver.bump_build()
@@ -439,7 +471,8 @@ build='build.10')
 
         :param part: One of "major", "minor", "patch", or "prerelease"
         :param prerelease_token: prefix string of prerelease, defaults to 'rc'
-        :return:
+        :return: new object with the appropriate part raised
+        :rtype: :class:`VersionInfo`
         """
         validparts = {
             "major",
@@ -463,7 +496,7 @@ build='build.10')
             return version.replace(prerelease=None, build=None)
 
         if part in ("major", "minor", "patch"):
-            return str(getattr(version, "bump_" + part)())
+            return getattr(version, "bump_" + part)()
 
         if not version.prerelease:
             version = version.bump_patch()
@@ -611,9 +644,9 @@ build='build.10')
         Parse version string to a VersionInfo instance.
 
         :param version: version string
-        :return: a :class:`semver.VersionInfo` instance
+        :return: a :class:`VersionInfo` instance
         :raises: :class:`ValueError`
-        :rtype: :class:`semver.VersionInfo`
+        :rtype: :class:`VersionInfo`
 
         >>> semver.VersionInfo.parse('3.4.5-pre.2+build.4')
         VersionInfo(major=3, minor=4, patch=5, \
@@ -634,14 +667,14 @@ prerelease='pre.2', build='build.4')
     def replace(self, **parts):
         """
         Replace one or more parts of a version and return a new
-        :class:`semver.VersionInfo` object, but leave self untouched
+        :class:`VersionInfo` object, but leave self untouched
 
         .. versionadded:: 2.9.0
            Added :func:`VersionInfo.replace`
 
         :param dict parts: the parts to be updated. Valid keys are:
           ``major``, ``minor``, ``patch``, ``prerelease``, or ``build``
-        :return: the new :class:`semver.VersionInfo` object with the changed
+        :return: the new :class:`VersionInfo` object with the changed
           parts
         :raises: :class:`TypeError`, if ``parts`` contains invalid keys
         """
@@ -942,12 +975,12 @@ def finalize_version(version):
     """
     Remove any prerelease and build metadata from the version string.
 
-    .. versionadded:: 2.7.9
-       Added :func:`finalize_version`
-
     .. deprecated:: 2.10.0
        Use :func:`semver.VersionInfo.finalize_version` instead.
 
+    .. versionadded:: 2.7.9
+       Added :func:`finalize_version`
+
     :param version: version string
     :return: the finalized version string
     :rtype: str
@@ -964,12 +997,12 @@ def replace(version, **parts):
     """
     Replace one or more parts of a version and return the new string.
 
-    .. versionadded:: 2.9.0
-       Added :func:`replace`
-
     .. deprecated:: 2.10.0
        Use :func:`semver.VersionInfo.replace` instead.
 
+    .. versionadded:: 2.9.0
+       Added :func:`replace`
+
     :param str version: the version string to replace
     :param dict parts: the parts to be updated. Valid keys are:
       ``major``, ``minor``, ``patch``, ``prerelease``, or ``build``
